"use strict";
const buildBase = require("./default");
const buildContracts = require("vso-node-api/interfaces/BuildInterfaces");
const trace = require("../../lib/trace");
function getCommand(args) {
    return new BuildShow(args);
}
exports.getCommand = getCommand;
class BuildShow extends buildBase.BuildBase {
    constructor() {
        super(...arguments);
        this.description = "Show build details.";
    }
    getHelpArgs() {
        return ["project", "buildId"];
    }
    exec() {
        trace.debug("build-show.exec");
        var buildapi = this.webApi.getBuildApi();
        return this.commandArgs.project.val().then((project) => {
            return this.commandArgs.buildId.val().then((buildId) => {
                return buildapi.getBuild(buildId, project);
            });
        });
    }
    friendlyOutput(build) {
        if (!build) {
            throw new Error("no build supplied");
        }
        trace.println();
        trace.info("id              : %s", build.id);
        trace.info("definition name : %s", build.definition ? build.definition.name : "unknown");
        trace.info("requested by    : %s", build.requestedBy ? build.requestedBy.displayName : "unknown");
        trace.info("status          : %s", buildContracts.BuildStatus[build.status]);
        trace.info("queue time      : %s", build.queueTime ? build.queueTime.toJSON() : "unknown");
    }
}
exports.BuildShow = BuildShow;
