"use strict";
const archiver = require('archiver');
const path = require('path');
const tasksBase = require("./default");
const trace = require('../../../lib/trace');
const vm = require('../../../lib/jsonvalidate');
function getCommand(args) {
    return new BuildTaskUpload(args);
}
exports.getCommand = getCommand;
var c_taskJsonFile = 'task.json';
class BuildTaskUpload extends tasksBase.BuildTaskBase {
    constructor() {
        super(...arguments);
        this.description = "Upload a Build Task.";
    }
    getHelpArgs() {
        return ["taskPath", "overwrite"];
    }
    exec() {
        return this.commandArgs.taskPath.val().then((taskPaths) => {
            let taskPath = taskPaths[0];
            return this.commandArgs.overwrite.val().then((overwrite) => {
                vm.exists(taskPath, 'specified directory ' + taskPath + ' does not exist.');
                //directory is good, check json
                let tp = path.join(taskPath, c_taskJsonFile);
                return vm.validate(tp, 'no ' + c_taskJsonFile + ' in specified directory').then((taskJson) => {
                    let archive = archiver('zip');
                    archive.on('error', function (error) {
                        trace.debug('Archiving error: ' + error.message);
                        error.message = 'Archiving error: ' + error.message;
                        throw error;
                    });
                    archive.directory(path.resolve(taskPath), false);
                    let agentApi = this.webApi.getTaskAgentApi(this.connection.getCollectionUrl());
                    archive.finalize();
                    return agentApi.uploadTaskDefinition(null, archive, taskJson.id, overwrite).then((task) => {
                        trace.debug('Success');
                        return {
                            sourceLocation: taskPath
                        };
                    });
                });
            });
        });
    }
    friendlyOutput(data) {
        trace.println();
        trace.success('Task at %s uploaded successfully!', data.sourceLocation);
    }
}
exports.BuildTaskUpload = BuildTaskUpload;
