"use strict";
const create_1 = require("./create");
const colors = require("colors");
const extBase = require("./default");
const Q = require("q");
const publishUtils = require("./_lib/publish");
const trace = require('../../lib/trace');
function getCommand(args) {
    return new ExtensionPublish(args);
}
exports.getCommand = getCommand;
class ExtensionPublish extends extBase.ExtensionBase {
    constructor() {
        super(...arguments);
        this.description = "Publish a Visual Studio Marketplace Extension.";
    }
    getHelpArgs() {
        return ["root", "manifests", "manifestGlobs", "override", "overridesFile", "bypassValidation", "publisher", "extensionId", "outputPath", "locRoot",
            "vsix", "shareWith"];
    }
    exec() {
        let galleryApi = this.webApi.getGalleryApi(this.webApi.serverUrl);
        let result = {};
        return this.getPublishSettings().then((publishSettings) => {
            let extensionCreatePromise;
            if (publishSettings.vsixPath) {
                result.packaged = null;
                extensionCreatePromise = Q.resolve(publishSettings.vsixPath);
            }
            else {
                extensionCreatePromise = this.getMergeSettings().then((mergeSettings) => {
                    return this.getPackageSettings().then((packageSettings) => {
                        return create_1.createExtension(mergeSettings, packageSettings);
                    });
                }).then((createResult) => {
                    result.packaged = createResult.path;
                    return createResult.path;
                });
            }
            return extensionCreatePromise.then((vsixPath) => {
                publishSettings.vsixPath = vsixPath;
                let packagePublisher = new publishUtils.PackagePublisher(publishSettings, galleryApi);
                return packagePublisher.publish().then((ext) => {
                    result.published = true;
                    if (publishSettings.shareWith && publishSettings.shareWith.length >= 0) {
                        let sharingMgr = new publishUtils.SharingManager(publishSettings, galleryApi);
                        return sharingMgr.shareWith(publishSettings.shareWith).then(() => {
                            result.shared = publishSettings.shareWith;
                            return result;
                        });
                    }
                    else {
                        result.shared = null;
                        return result;
                    }
                });
            });
        });
    }
    friendlyOutput(data) {
        trace.info(colors.green("\n=== Completed operation: publish extension ==="));
        let packagingStr = data.packaged ? colors.green(data.packaged) : colors.yellow("not packaged (existing package used)");
        let publishingStr = data.published ? colors.green("success") : colors.yellow("???");
        let sharingStr = data.shared ? "shared with " + data.shared.map(s => colors.green(s)).join(", ") : colors.yellow("not shared (use --share-with to share)");
        trace.info(" - Packaging: %s", packagingStr);
        trace.info(" - Publishing: %s", publishingStr);
        trace.info(" - Sharing: %s", sharingStr);
    }
}
exports.ExtensionPublish = ExtensionPublish;
