"use strict";
const extPubBase = require("./default");
const trace = require('../../../lib/trace');
function getCommand(args) {
    // this just offers description for help and to offer sub commands
    return new ExtensionPublisherCreate(args);
}
exports.getCommand = getCommand;
class ExtensionPublisherCreate extends extPubBase.ExtensionPublisherBase {
    constructor() {
        super(...arguments);
        this.description = "Create a Visual Studio Services Market publisher";
    }
    getHelpArgs() {
        return ["publisher", "displayName", "description"];
    }
    exec() {
        let galleryApi = this.webApi.getGalleryApi(this.webApi.serverUrl);
        return Promise.all([
            this.commandArgs.publisher.val(),
            this.commandArgs.displayName.val(),
            this.commandArgs.description.val()
        ]).then((values) => {
            const [publisherName, displayName, description] = values;
            return galleryApi.createPublisher({
                publisherName: publisherName,
                displayName: displayName,
                shortDescription: description,
                longDescription: description
            });
        });
    }
    friendlyOutput(data) {
        trace.success("\n=== Completed operation: create publisher ===");
        trace.info(" - Name: %s", data.publisherName);
        trace.info(" - Display Name: %s", data.displayName);
        trace.info(" - Description: %s", data.longDescription);
    }
}
exports.ExtensionPublisherCreate = ExtensionPublisherCreate;
