"use strict";
const tfcommand_1 = require("../lib/tfcommand");
const diskcache_1 = require("../lib/diskcache");
const credstore_1 = require("../lib/credstore");
const colors = require("colors");
const Q = require('q');
const os = require('os');
const trace = require('../lib/trace');
function getCommand(args) {
    // this just offers description for help and to offer sub commands
    return new Login(args);
}
exports.getCommand = getCommand;
/**
 * Facilitates a "log in" to a service by caching credentials.
 */
class Login extends tfcommand_1.TfCommand {
    constructor() {
        super(...arguments);
        this.description = "Login and cache credentials using a PAT or basic auth.";
    }
    exec() {
        trace.debug('Login.exec');
        let authHandler;
        return this.commandArgs.serviceUrl.val().then((collectionUrl) => {
            return this.getCredentials(collectionUrl, false).then((handler) => {
                authHandler = handler;
                return this.getWebApi();
            }).then((webApi) => {
                let agentApi = webApi.getTaskAgentApi();
                return Q.Promise((resolve, reject) => {
                    return agentApi.connect().then((obj) => {
                        let tfxCredStore = credstore_1.getCredentialStore("tfx");
                        let tfxCache = new diskcache_1.DiskCache("tfx");
                        let credString;
                        if (authHandler.username === "OAuth") {
                            credString = "pat:" + authHandler.password;
                        }
                        else {
                            credString = "basic:" + authHandler.username + ":" + authHandler.password;
                        }
                        return tfxCredStore.storeCredential(collectionUrl, "allusers", credString).then(() => {
                            return tfxCache.setItem("cache", "connection", collectionUrl);
                        });
                    }).catch((err) => {
                        if (err && err.statusCode && err.statusCode === 401) {
                            trace.debug("Connection failed: invalid credentials.");
                            throw "Invalid credentials.";
                        }
                        else if (err) {
                            trace.debug("Connection failed.");
                            throw "Connection failed. Check your internet connection & collection URL." + os.EOL + "Message: " + err.message;
                        }
                    });
                });
            });
        });
    }
    friendlyOutput(data) {
        if (data.success) {
            trace.info(colors.green("Logged in successfully"));
        }
        else {
            trace.error("login unsuccessful.");
        }
    }
}
exports.Login = Login;
