"use strict";
const witBase = require("./default");
function getCommand(args) {
    return new WorkItemQuery(args);
}
exports.getCommand = getCommand;
class WorkItemQuery extends witBase.WorkItemBase {
    constructor() {
        super(...arguments);
        this.description = "Get a list of Work Items given a query";
    }
    getHelpArgs() {
        return ["project", "query"];
    }
    exec() {
        var witApi = this.webApi.getWorkItemTrackingApi();
        return this.commandArgs.project.val(true).then((projectName) => {
            return this.commandArgs.query.val().then((query) => {
                let wiql = { query: query };
                return witApi.queryByWiql(wiql, { project: projectName }).then((result) => {
                    let workItemIds = result.workItems.map(val => val.id).slice(0, Math.min(200, result.workItems.length));
                    let fieldRefs = result.columns.map(val => val.referenceName);
                    fieldRefs = fieldRefs.slice(0, Math.min(20, result.columns.length));
                    return witApi.getWorkItems(workItemIds, fieldRefs);
                });
            });
        });
    }
    friendlyOutput(data) {
        return witBase.friendlyOutput(data);
    }
}
exports.WorkItemQuery = WorkItemQuery;
