"use strict";
const common = require("./common");
const fs = require("./qfs");
const path = require("path");
function getCommand() {
    let args = process.argv.slice(2);
    return getCommandHierarchy(path.resolve(common.APP_ROOT, "exec")).then((hierarchy) => {
        let execPath = [];
        let commandArgs = [];
        let currentHierarchy = hierarchy;
        let inArgs = false;
        args.forEach((arg) => {
            if (currentHierarchy && currentHierarchy[arg] !== undefined) {
                currentHierarchy = currentHierarchy[arg];
                execPath.push(arg);
            }
            else if (arg.substr(0, 2) === "--" || inArgs) {
                commandArgs.push(arg);
                inArgs = true;
            }
            else {
                throw "Command '" + arg + "' not found. For help, type tfx " + execPath.join(" ") + " --help";
            }
        });
        return {
            execPath: execPath,
            args: commandArgs,
            commandHierarchy: hierarchy
        };
    });
}
exports.getCommand = getCommand;
function getCommandHierarchy(root) {
    let hierarchy = {};
    return fs.readdir(root).then((files) => {
        let filePromises = [];
        files.forEach((file) => {
            if (file.substr(0, 1) === "_") {
                return;
            }
            let fullPath = path.resolve(root, file);
            let parsedPath = path.parse(fullPath);
            let promise = fs.lstat(fullPath).then((stats) => {
                if (stats.isDirectory()) {
                    return getCommandHierarchy(fullPath).then((subHierarchy) => {
                        hierarchy[parsedPath.name] = subHierarchy;
                    });
                }
                else {
                    hierarchy[parsedPath.name] = null;
                    return null;
                }
            });
            filePromises.push(promise);
        });
        return Promise.all(filePromises).then(() => {
            return hierarchy;
        });
    });
}
